==> managedblockchain-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/managedblockchain/CfnNodeProps.java <==
package software.amazon.awscdk.services.managedblockchain;

/**
 * Properties for defining a `AWS::ManagedBlockchain::Node`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:17:29.348Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnNodeProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ManagedBlockchain::Node.MemberId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-memberid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getMemberId();

    /**
     * `AWS::ManagedBlockchain::Node.NetworkId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-networkid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getNetworkId();

    /**
     * `AWS::ManagedBlockchain::Node.NodeConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-nodeconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getNodeConfiguration();

    /**
     * @return a {@link Builder} of {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String memberId;
        private java.lang.String networkId;
        private java.lang.Object nodeConfiguration;

        /**
         * Sets the value of MemberId
         * @param memberId `AWS::ManagedBlockchain::Node.MemberId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberId(java.lang.String memberId) {
            this.memberId = memberId;
            return this;
        }

        /**
         * Sets the value of NetworkId
         * @param networkId `AWS::ManagedBlockchain::Node.NetworkId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkId(java.lang.String networkId) {
            this.networkId = networkId;
            return this;
        }

        /**
         * Sets the value of NodeConfiguration
         * @param nodeConfiguration `AWS::ManagedBlockchain::Node.NodeConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder nodeConfiguration(software.amazon.awscdk.core.IResolvable nodeConfiguration) {
            this.nodeConfiguration = nodeConfiguration;
            return this;
        }

        /**
         * Sets the value of NodeConfiguration
         * @param nodeConfiguration `AWS::ManagedBlockchain::Node.NodeConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder nodeConfiguration(software.amazon.awscdk.services.managedblockchain.CfnNode.NodeConfigurationProperty nodeConfiguration) {
            this.nodeConfiguration = nodeConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNodeProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnNodeProps build() {
            return new Jsii$Proxy(memberId, networkId, nodeConfiguration);
        }
    }

    /**
     * An implementation for {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNodeProps {
        private final java.lang.String memberId;
        private final java.lang.String networkId;
        private final java.lang.Object nodeConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.memberId = this.jsiiGet("memberId", java.lang.String.class);
            this.networkId = this.jsiiGet("networkId", java.lang.String.class);
            this.nodeConfiguration = this.jsiiGet("nodeConfiguration", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String memberId, java.lang.String networkId, java.lang.Object nodeConfiguration) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.memberId = java.util.Objects.requireNonNull(memberId, "memberId is required");
            this.networkId = java.util.Objects.requireNonNull(networkId, "networkId is required");
            this.nodeConfiguration = java.util.Objects.requireNonNull(nodeConfiguration, "nodeConfiguration is required");
        }

        @Override
        public java.lang.String getMemberId() {
            return this.memberId;
        }

        @Override
        public java.lang.String getNetworkId() {
            return this.networkId;
        }

        @Override
        public java.lang.Object getNodeConfiguration() {
            return this.nodeConfiguration;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("memberId", om.valueToTree(this.getMemberId()));
            obj.set("networkId", om.valueToTree(this.getNetworkId()));
            obj.set("nodeConfiguration", om.valueToTree(this.getNodeConfiguration()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNodeProps.Jsii$Proxy that = (CfnNodeProps.Jsii$Proxy) o;

            if (!memberId.equals(that.memberId)) return false;
            if (!networkId.equals(that.networkId)) return false;
            return this.nodeConfiguration.equals(that.nodeConfiguration);
        }

        @Override
        public int hashCode() {
            int result = this.memberId.hashCode();
            result = 31 * result + (this.networkId.hashCode());
            result = 31 * result + (this.nodeConfiguration.hashCode());
            return result;
        }
    }
}

==> managedblockchain-1.16.2.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/managedblockchain/CfnNodeProps.java <==
package software.amazon.awscdk.services.managedblockchain;

/**
 * Properties for defining a `AWS::ManagedBlockchain::Node`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.4 (build 96d89e1)", date = "2019-11-12T11:54:40.612Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.managedblockchain.$Module.class, fqn = "@aws-cdk/aws-managedblockchain.CfnNodeProps")
@software.amazon.jsii.Jsii.Proxy(CfnNodeProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnNodeProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ManagedBlockchain::Node.MemberId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-memberid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getMemberId();

    /**
     * `AWS::ManagedBlockchain::Node.NetworkId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-networkid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getNetworkId();

    /**
     * `AWS::ManagedBlockchain::Node.NodeConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-node.html#cfn-managedblockchain-node-nodeconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getNodeConfiguration();

    /**
     * @return a {@link Builder} of {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String memberId;
        private java.lang.String networkId;
        private java.lang.Object nodeConfiguration;

        /**
         * Sets the value of MemberId
         * @param memberId `AWS::ManagedBlockchain::Node.MemberId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberId(java.lang.String memberId) {
            this.memberId = memberId;
            return this;
        }

        /**
         * Sets the value of NetworkId
         * @param networkId `AWS::ManagedBlockchain::Node.NetworkId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkId(java.lang.String networkId) {
            this.networkId = networkId;
            return this;
        }

        /**
         * Sets the value of NodeConfiguration
         * @param nodeConfiguration `AWS::ManagedBlockchain::Node.NodeConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder nodeConfiguration(software.amazon.awscdk.core.IResolvable nodeConfiguration) {
            this.nodeConfiguration = nodeConfiguration;
            return this;
        }

        /**
         * Sets the value of NodeConfiguration
         * @param nodeConfiguration `AWS::ManagedBlockchain::Node.NodeConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder nodeConfiguration(software.amazon.awscdk.services.managedblockchain.CfnNode.NodeConfigurationProperty nodeConfiguration) {
            this.nodeConfiguration = nodeConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNodeProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnNodeProps build() {
            return new Jsii$Proxy(memberId, networkId, nodeConfiguration);
        }
    }

    /**
     * An implementation for {@link CfnNodeProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNodeProps {
        private final java.lang.String memberId;
        private final java.lang.String networkId;
        private final java.lang.Object nodeConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.memberId = this.jsiiGet("memberId", java.lang.String.class);
            this.networkId = this.jsiiGet("networkId", java.lang.String.class);
            this.nodeConfiguration = this.jsiiGet("nodeConfiguration", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String memberId, final java.lang.String networkId, final java.lang.Object nodeConfiguration) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.memberId = java.util.Objects.requireNonNull(memberId, "memberId is required");
            this.networkId = java.util.Objects.requireNonNull(networkId, "networkId is required");
            this.nodeConfiguration = java.util.Objects.requireNonNull(nodeConfiguration, "nodeConfiguration is required");
        }

        @Override
        public java.lang.String getMemberId() {
            return this.memberId;
        }

        @Override
        public java.lang.String getNetworkId() {
            return this.networkId;
        }

        @Override
        public java.lang.Object getNodeConfiguration() {
            return this.nodeConfiguration;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("memberId", om.valueToTree(this.getMemberId()));
            data.set("networkId", om.valueToTree(this.getNetworkId()));
            data.set("nodeConfiguration", om.valueToTree(this.getNodeConfiguration()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-managedblockchain.CfnNodeProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNodeProps.Jsii$Proxy that = (CfnNodeProps.Jsii$Proxy) o;

            if (!memberId.equals(that.memberId)) return false;
            if (!networkId.equals(that.networkId)) return false;
            return this.nodeConfiguration.equals(that.nodeConfiguration);
        }

        @Override
        public int hashCode() {
            int result = this.memberId.hashCode();
            result = 31 * result + (this.networkId.hashCode());
            result = 31 * result + (this.nodeConfiguration.hashCode());
            return result;
        }
    }
}
